
## Gree Climate
Discover, connect and control Gree based mini-split systems.

__greenclimat__ is a Python3 based package for controll Gree mini-split ACs and heat pumps. Gree is a common brand for minisplit systems and is licensed and resold under many product names. This module may (or may not) work for any of those system, but has been tested on

- Trane mini-split heat pump (4TXK38)

_If you have tested and know of others systems that work, please fork and submit a PR with the make and model_

__Based on the following work__
- [Gree Remote by tomikaa87](https://github.com/tomikaa87/gree-remote)

## Getting the package
The easiest way to grab __greeclimate__ is through PyPI
`pip3 install greeclimate`

## Use Gree Climate

....

WIP, more details will come once testing is completed

....